@@ -29,8 +29,8 @@
 //! This implementation is based on the following draft:
 //! <https://tools.ietf.org/html/draft-cardwell-iccrg-bbr-congestion-control-00>
 
+use super::*;
 use crate::minmax::Minmax;
-use crate::recovery::*;
 
 use std::time::Duration;
 
@@ -351,22 +351,25 @@ fn debug_fmt(r: &Congestion, f: &mut std::fmt::Formatter) -> std::fmt::Result {
 mod tests {
     use super::*;
 
-    use crate::recovery;
-
-    use self::congestion::test_sender::TestSender;
+    use crate::packet;
+    use crate::ranges;
+    use crate::recovery::congestion::recovery::LegacyRecovery;
+    use crate::recovery::congestion::test_sender::TestSender;
+    use crate::recovery::HandshakeStatus;
+    use crate::recovery::RecoveryOps;
 
     use smallvec::smallvec;
 
     fn test_sender() -> TestSender {
-        TestSender::new(recovery::CongestionControlAlgorithm::BBR, false)
+        TestSender::new(CongestionControlAlgorithm::BBR, false)
     }
 
     #[test]
     fn bbr_init() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR);
 
-        let r = Recovery::new(&cfg);
+        let r = LegacyRecovery::new(&cfg);
 
         assert_eq!(
             r.cwnd(),
@@ -410,9 +413,9 @@ mod tests {
     #[test]
     fn bbr_congestion_event() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR);
 
-        let mut r = Recovery::new(&cfg);
+        let mut r = LegacyRecovery::new(&cfg);
         let now = Instant::now();
         let mss = r.max_datagram_size;
 
@@ -463,7 +466,7 @@ mod tests {
                 now,
                 "",
             ),
-            Ok((2, 2 * mss, mss)),
+            (2, 2 * mss, mss),
         );
 
         // Sent: 0, 1, 2, 3, 4, Acked 4.
@@ -475,9 +478,9 @@ mod tests {
     #[test]
     fn bbr_drain() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR);
 
-        let mut r = Recovery::new(&cfg);
+        let mut r = LegacyRecovery::new(&cfg);
         let now = Instant::now();
         let mss = r.max_datagram_size;
 
@@ -530,7 +533,7 @@ mod tests {
                     now,
                     "",
                 ),
-                Ok((0, 0, mss)),
+                (0, 0, mss),
             );
         }
 
@@ -584,7 +587,7 @@ mod tests {
                 now,
                 "",
             ),
-            Ok((0, 0, mss)),
+            (0, 0, mss),
         );
 
         // Now we are in Drain state.
@@ -596,9 +599,9 @@ mod tests {
     #[test]
     fn bbr_probe_bw() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR);
 
-        let mut r = Recovery::new(&cfg);
+        let mut r = LegacyRecovery::new(&cfg);
         let now = Instant::now();
         let mss = r.max_datagram_size;
 
@@ -648,7 +651,7 @@ mod tests {
                     now,
                     "",
                 ),
-                Ok((0, 0, mss)),
+                (0, 0, mss),
             );
         }
 
@@ -663,9 +666,9 @@ mod tests {
     #[test]
     fn bbr_probe_rtt() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR);
 
-        let mut r = Recovery::new(&cfg);
+        let mut r = LegacyRecovery::new(&cfg);
         let now = Instant::now();
         let mss = r.max_datagram_size;
 
@@ -719,7 +722,7 @@ mod tests {
                     now,
                     "",
                 ),
-                Ok((0, 0, mss)),
+                (0, 0, mss),
             );
         }
 
@@ -775,7 +778,7 @@ mod tests {
                 now,
                 "",
             ),
-            Ok((0, 0, mss)),
+            (0, 0, mss),
         );
 
         assert_eq!(r.congestion.bbr_state.state, BBRStateMachine::ProbeRTT);
