@@ -29,8 +29,8 @@
 //! This implementation is based on the following draft:
 //! <https://tools.ietf.org/html/draft-cardwell-iccrg-bbr-congestion-control-02>
 
+use super::*;
 use crate::minmax::Minmax;
-use crate::recovery::*;
 
 use std::time::Duration;
 use std::time::Instant;
@@ -663,14 +663,19 @@ mod tests {
 
     use smallvec::smallvec;
 
-    use crate::recovery;
+    use crate::packet;
+    use crate::ranges;
+    use crate::recovery::congestion::recovery::LegacyRecovery;
+    use crate::recovery::HandshakeStatus;
+    use crate::recovery::RecoveryOps;
+    use crate::CongestionControlAlgorithm;
 
     #[test]
     fn bbr_init() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR2);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR2);
 
-        let r = Recovery::new(&cfg);
+        let r = LegacyRecovery::new(&cfg);
 
         // on_init() is called in Connection::new(), so it need to be
         // called manually here.
@@ -687,9 +692,9 @@ mod tests {
     #[test]
     fn bbr2_startup() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR2);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR2);
 
-        let mut r = Recovery::new(&cfg);
+        let mut r = LegacyRecovery::new(&cfg);
         let now = Instant::now();
         let mss = r.max_datagram_size;
 
@@ -730,16 +735,17 @@ mod tests {
         let mut acked = ranges::RangeSet::default();
         acked.insert(0..5);
 
-        assert!(r
-            .on_ack_received(
+        assert_eq!(
+            r.on_ack_received(
                 &acked,
                 25,
                 packet::Epoch::Application,
                 HandshakeStatus::default(),
                 now,
                 "",
-            )
-            .is_ok());
+            ),
+            (0, 0, 5 * mss)
+        );
 
         assert_eq!(r.congestion.bbr2_state.state, BBR2StateMachine::Startup);
         assert_eq!(r.cwnd(), cwnd_prev + mss * 5);
@@ -754,9 +760,9 @@ mod tests {
     #[test]
     fn bbr2_congestion_event() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR2);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR2);
 
-        let mut r = Recovery::new(&cfg);
+        let mut r = LegacyRecovery::new(&cfg);
         let now = Instant::now();
         let mss = r.max_datagram_size;
 
@@ -798,16 +804,17 @@ mod tests {
         acked.insert(4..5);
 
         // 2 acked, 2 x MSS lost.
-        assert!(r
-            .on_ack_received(
+        assert_eq!(
+            r.on_ack_received(
                 &acked,
                 25,
                 packet::Epoch::Application,
                 HandshakeStatus::default(),
                 now,
                 "",
-            )
-            .is_ok());
+            ),
+            (2, 2 * mss, mss)
+        );
 
         assert!(r.congestion.bbr2_state.in_recovery);
 
@@ -822,9 +829,9 @@ mod tests {
     #[test]
     fn bbr2_probe_bw() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR2);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR2);
 
-        let mut r = Recovery::new(&cfg);
+        let mut r = LegacyRecovery::new(&cfg);
         let now = Instant::now();
         let mss = r.max_datagram_size;
 
@@ -868,16 +875,17 @@ mod tests {
             let mut acked = ranges::RangeSet::default();
             acked.insert(0..pn);
 
-            assert!(r
-                .on_ack_received(
+            assert_eq!(
+                r.on_ack_received(
                     &acked,
                     25,
                     packet::Epoch::Application,
                     HandshakeStatus::default(),
                     now,
                     "",
-                )
-                .is_ok());
+                ),
+                (0, 0, mss)
+            );
         }
 
         // Stop at right before filled_pipe=true.
@@ -921,16 +929,17 @@ mod tests {
         // in Drain state.
         acked.insert(0..pn - 4);
 
-        assert!(r
-            .on_ack_received(
+        assert_eq!(
+            r.on_ack_received(
                 &acked,
                 25,
                 packet::Epoch::Application,
                 HandshakeStatus::default(),
                 now,
                 "",
-            )
-            .is_ok());
+            ),
+            (0, 0, mss)
+        );
 
         assert_eq!(r.congestion.bbr2_state.state, BBR2StateMachine::Drain);
         assert!(r.congestion.bbr2_state.filled_pipe);
@@ -940,9 +949,9 @@ mod tests {
     #[test]
     fn bbr2_probe_rtt() {
         let mut cfg = crate::Config::new(crate::PROTOCOL_VERSION).unwrap();
-        cfg.set_cc_algorithm(recovery::CongestionControlAlgorithm::BBR2);
+        cfg.set_cc_algorithm(CongestionControlAlgorithm::BBR2);
 
-        let mut r = Recovery::new(&cfg);
+        let mut r = LegacyRecovery::new(&cfg);
         let now = Instant::now();
         let mss = r.max_datagram_size;
 
@@ -987,16 +996,17 @@ mod tests {
             let mut acked = ranges::RangeSet::default();
             acked.insert(0..pn);
 
-            assert!(r
-                .on_ack_received(
+            assert_eq!(
+                r.on_ack_received(
                     &acked,
                     25,
                     packet::Epoch::Application,
                     HandshakeStatus::default(),
                     now,
                     "",
-                )
-                .is_ok());
+                ),
+                (0, 0, mss)
+            );
         }
 
         // Now we are in ProbeBW state.
@@ -1045,16 +1055,17 @@ mod tests {
         let mut acked = ranges::RangeSet::default();
         acked.insert(0..pn);
 
-        assert!(r
-            .on_ack_received(
+        assert_eq!(
+            r.on_ack_received(
                 &acked,
                 25,
                 packet::Epoch::Application,
                 HandshakeStatus::default(),
                 now,
                 "",
-            )
-            .is_ok());
+            ),
+            (0, 0, mss)
+        );
 
         assert_eq!(r.congestion.bbr2_state.state, BBR2StateMachine::ProbeRTT);
         assert_eq!(r.congestion.bbr2_state.pacing_gain, 1.0);
